package com.rjconsultores.ventaboletos.web.gui.controladores.relatorios;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.sql.DataSource;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Controller;
import org.zkoss.util.resource.Labels;
import org.zkoss.zhtml.Messagebox;
import org.zkoss.zk.ui.Component;
import org.zkoss.zk.ui.event.Event;
import org.zkoss.zul.Bandbox;
import org.zkoss.zul.Comboitem;
import org.zkoss.zul.Datebox;
import org.zkoss.zul.Paging;

import com.rjconsultores.ventaboletos.entidad.Empresa;
import com.rjconsultores.ventaboletos.entidad.PuntoVenta;
import com.rjconsultores.ventaboletos.entidad.Usuario;
import com.rjconsultores.ventaboletos.relatorios.impl.RelatorioTrocoSimples;
import com.rjconsultores.ventaboletos.relatorios.utilitarios.Relatorio;
import com.rjconsultores.ventaboletos.service.EmpresaService;
import com.rjconsultores.ventaboletos.utilerias.UsuarioLogado;
import com.rjconsultores.ventaboletos.web.utilerias.MyComboboxEstandar;
import com.rjconsultores.ventaboletos.web.utilerias.MyComboboxUsuario;
import com.rjconsultores.ventaboletos.web.utilerias.MyGenericForwardComposer;
import com.rjconsultores.ventaboletos.web.utilerias.MyListbox;
import com.rjconsultores.ventaboletos.web.utilerias.MyTextbox;
import com.rjconsultores.ventaboletos.web.utilerias.paginacion.HibernateSearchObject;
import com.rjconsultores.ventaboletos.web.utilerias.paginacion.PagedListWrapper;
import com.rjconsultores.ventaboletos.web.utilerias.render.RenderRelatorioVendasBilheteiro;
import com.rjconsultores.ventaboletos.web.utilerias.render.RenderRelatorioVendasBilheteiroSelecionados;

@Controller("relatorioTrocoSimplesController")
@Scope("prototype")
public class RelatorioTrocoSimplesController extends MyGenericForwardComposer {

	private static final long serialVersionUID = 1L;

	private Datebox dtInicial;
	private Datebox dtFinal;

	private MyComboboxEstandar cmbEmpresa;
	private List<Empresa> lsEmpresa;

	@Autowired
	private transient PagedListWrapper<PuntoVenta> plwPuntoVenta;
	private MyTextbox txtNombrePuntoVenta;
	private Bandbox bbPesquisaPuntoVenta;
	private Paging pagingPuntoVenta;
	private MyListbox puntoVentaList;
	private MyListbox puntoVentaSelList;
	
	private MyComboboxUsuario cmbUsuario;
	
	@Autowired
	private EmpresaService empresaService;
	@Autowired
	private DataSource dataSourceRead;

	@Override
	public void doAfterCompose(Component comp) throws Exception {
		lsEmpresa = empresaService.obtenerTodos();
		super.doAfterCompose(comp);

		puntoVentaList.setItemRenderer(new RenderRelatorioVendasBilheteiro());
		puntoVentaSelList.setItemRenderer(new RenderRelatorioVendasBilheteiroSelecionados());
	}

	@SuppressWarnings({ "rawtypes", "unchecked" })
	private void executarRelatorio() throws Exception {
		Relatorio relatorio;
		Map<String, Object> parametros = new HashMap<String, Object>();
		StringBuilder filtro = new StringBuilder();
		SimpleDateFormat format = new SimpleDateFormat("dd/MM/yyyy");

		if (!validar()) {
			return;
		}

		if (dtInicial.getValue() != null) {
			filtro.append("Período: ")
					.append(format.format(dtInicial.getValue()))
					.append(" - ")
					.append(format.format(dtFinal.getValue()))
					.append(";");
		}

		filtro.append("Agência: ");
		String puntoVentaIds = "";
		String puntoVentas = "";
		List<PuntoVenta> lsPuntoVentaSelecionados = new ArrayList(Arrays.asList(puntoVentaSelList.getData()));
		if (lsPuntoVentaSelecionados.size() > 0) {
			for (int i = 0; i < lsPuntoVentaSelecionados.size(); i++) {
				PuntoVenta puntoVenta = lsPuntoVentaSelecionados.get(i);
				puntoVentas = puntoVentas + puntoVenta.getNombpuntoventa() + ",";
				puntoVentaIds = puntoVentaIds + puntoVenta.getPuntoventaId() + ",";
			}

			puntoVentaIds = puntoVentaIds.substring(0, puntoVentaIds.length() - 1);
			puntoVentas = puntoVentas.substring(0, puntoVentas.length() - 1);
			parametros.put("NUMPUNTOVENTA", puntoVentaIds);
		} else {
			filtro.append("Todas  ");
		}

		filtro.append(puntoVentas).append(";");
		
		
		filtro.append("Bilheteiro: ");
		Comboitem itemUsuario = cmbUsuario.getSelectedItem();
		if (itemUsuario != null) {
			Usuario usuario = (Usuario) itemUsuario.getValue();
			if(usuario.getUsuarioId() != -1) {
			parametros.put("BILHETEIRO_ID", usuario.getUsuarioId());
			filtro.append(usuario.getNombusuario() + ";");
			}else {
				filtro.append(" Todos;  ");
			}
		} else {
			filtro.append(" Todos;  ");
		}
		
		parametros.put("DATA_INICIAL", (java.util.Date) dtInicial.getValue());
		parametros.put("DATA_FINAL", (java.util.Date) dtFinal.getValue());

		parametros.put("NOME_RELATORIO", Labels.getLabel("relatorioTrocoSimples.window.title"));
		parametros.put("USUARIO", UsuarioLogado.getUsuarioLogado().getUsuarioId().toString());
		parametros.put("USUARIO_NOME", UsuarioLogado.getUsuarioLogado().getNombusuario());

		
		filtro.append("Empresa: ");
		Comboitem itemEmpresa = cmbEmpresa.getSelectedItem();
		if (itemEmpresa != null) {
			Empresa empresa = (Empresa) itemEmpresa.getValue();
			parametros.put("EMPRESA_ID", empresa.getEmpresaId());
			filtro.append(empresa.getNombempresa() + ";");
		} else {
			filtro.append(" Todas;  ");
		}

		parametros.put("FILTROS", filtro.toString());
		relatorio = new RelatorioTrocoSimples(parametros, dataSourceRead.getConnection());

		Map args = new HashMap();
		args.put("relatorio", relatorio);

		openWindow("/component/reportView.zul",
				Labels.getLabel("relatorioTrocoSimples.window.title"), args, MODAL);
	}

	private boolean validar() {
		try {
			if (dtInicial.getValue() == null || dtFinal.getValue() == null) {
				Messagebox.show(Labels.getLabel("relatorioTrocoSimples.MSG.informarDatas"), 
						Labels.getLabel("relatorioTrocoSimples.window.title"),
						Messagebox.OK, Messagebox.INFORMATION);
				return false;
			}
		} catch (InterruptedException ex) {
			return false;
		}
		return true;
	}

	public void onClick$btnExecutarRelatorio(Event ev) throws Exception {
		executarRelatorio();
	}

	private void executarPesquisa() {
		HibernateSearchObject<PuntoVenta> puntoVentaBusqueda = new HibernateSearchObject<PuntoVenta>(PuntoVenta.class, pagingPuntoVenta.getPageSize());

		puntoVentaBusqueda.addFilterILike("nombpuntoventa", "%" + txtNombrePuntoVenta.getValue() + "%");
		puntoVentaBusqueda.addFilterEqual(ACTIVO, Boolean.TRUE);
		puntoVentaBusqueda.addFilterNotEqual("puntoventaId", -1);
		puntoVentaBusqueda.addSortAsc("nombpuntoventa");
		puntoVentaBusqueda.addFilterEqual(ACTIVO, Boolean.TRUE);
		plwPuntoVenta.init(puntoVentaBusqueda, puntoVentaList, pagingPuntoVenta);

		if (puntoVentaList.getData().length == 0) {
			try {
				Messagebox.show(Labels.getLabel("MSG.ningunRegistro"),
						Labels.getLabel("relatorioVendasBilheteiroController.window.title"),
						Messagebox.OK, Messagebox.INFORMATION);
			} catch (InterruptedException ex) {
				ex.printStackTrace();
			}
		}
	}

	public void onClick$btnPesquisa(Event ev) {
		executarPesquisa();
	}

	public void onDoubleClick$puntoVentaSelList(Event ev) {
		PuntoVenta puntoVenta = (PuntoVenta) puntoVentaSelList.getSelected();
		puntoVentaSelList.removeItem(puntoVenta);
	}

	public void onDoubleClick$puntoVentaList(Event ev) {
		PuntoVenta puntoVenta = (PuntoVenta) puntoVentaList.getSelected();
		puntoVentaSelList.addItemNovo(puntoVenta);
	}
	
	public void onClick$btnLimpar(Event ev) {
		puntoVentaList.setData(new ArrayList<PuntoVenta>());
		bbPesquisaPuntoVenta.setText("");
	}

	public List<Empresa> getLsEmpresa() {
		return lsEmpresa;
	}

	public void setLsEmpresa(List<Empresa> lsEmpresa) {
		this.lsEmpresa = lsEmpresa;
	}

	public MyComboboxEstandar getCmbEmpresa() {
		return cmbEmpresa;
	}

	public void setCmbEmpresa(MyComboboxEstandar cmbEmpresa) {
		this.cmbEmpresa = cmbEmpresa;
	}

	public PagedListWrapper<PuntoVenta> getPlwPuntoVenta() {
		return plwPuntoVenta;
	}

	public void setPlwPuntoVenta(PagedListWrapper<PuntoVenta> plwPuntoVenta) {
		this.plwPuntoVenta = plwPuntoVenta;
	}

	public MyTextbox getTxtNombrePuntoVenta() {
		return txtNombrePuntoVenta;
	}

	public void setTxtNombrePuntoVenta(MyTextbox txtNombrePuntoVenta) {
		this.txtNombrePuntoVenta = txtNombrePuntoVenta;
	}

	public MyListbox getPuntoVentaList() {
		return puntoVentaList;
	}

	public void setPuntoVentaList(MyListbox puntoVentaList) {
		this.puntoVentaList = puntoVentaList;
	}

	public MyListbox getPuntoVentaSelList() {
		return puntoVentaSelList;
	}

	public void setPuntoVentaSelList(MyListbox puntoVentaSelList) {
		this.puntoVentaSelList = puntoVentaSelList;
	}

	public Datebox getDtVendaInicial() {
		return dtInicial;
	}

	public void setDtVendaInicial(Datebox dtVendaInicial) {
		this.dtInicial = dtVendaInicial;
	}

	public Datebox getDtVendaFinal() {
		return dtFinal;
	}

	public void setDtVendaFinal(Datebox dtVendaFinal) {
		this.dtFinal = dtVendaFinal;
	}
	
}
