package com.rjconsultores.ventaboletos.web.gui.controladores.tarifas;

import java.util.HashMap;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Controller;
import org.zkoss.util.resource.Labels;
import org.zkoss.zhtml.Messagebox;
import org.zkoss.zk.ui.Component;
import org.zkoss.zk.ui.event.Event;
import org.zkoss.zk.ui.event.EventListener;
import org.zkoss.zul.Paging;

import com.rjconsultores.ventaboletos.entidad.AsistenciaDeViajeEmpresa;
import com.rjconsultores.ventaboletos.web.utilerias.MyGenericForwardComposer;
import com.rjconsultores.ventaboletos.web.utilerias.MyListbox;
import com.rjconsultores.ventaboletos.web.utilerias.paginacion.HibernateSearchObject;
import com.rjconsultores.ventaboletos.web.utilerias.paginacion.PagedListWrapper;
import com.rjconsultores.ventaboletos.web.utilerias.render.RenderAsistenciaDeViajeEmpresa;

@Controller("busquedaAsistenciaDeViajeEmpresaController")
@Scope("prototype")
public class BusquedaAsistenciaDeViajeEmpresaController extends MyGenericForwardComposer {

	private static final long serialVersionUID = 1L;

	@Autowired
	private transient PagedListWrapper<AsistenciaDeViajeEmpresa> plwAsistenciaDeViajeEmpresa;

	private MyListbox asistenciaDeViajeEmpresaList;
	private Paging pagingAsistenciaDeViajeEmpresa;

	@Override
	public void doAfterCompose(Component comp) throws Exception {
		super.doAfterCompose(comp);

		asistenciaDeViajeEmpresaList.setItemRenderer(new RenderAsistenciaDeViajeEmpresa());
		asistenciaDeViajeEmpresaList.addEventListener("onDoubleClick", new EventListener() {

			@Override
			public void onEvent(Event event) throws Exception {
				AsistenciaDeViajeEmpresa entity = (AsistenciaDeViajeEmpresa) asistenciaDeViajeEmpresaList.getSelected();
				verAsistenciaDeViajeEmpresa(entity);
			}
		});

		refreshLista();
	}

	@SuppressWarnings({ "unchecked", "rawtypes" })
	private void verAsistenciaDeViajeEmpresa(AsistenciaDeViajeEmpresa entity) {
		if (entity == null) {
			return;
		}

		Map args = new HashMap();
		args.put("asistenciaDeViajeEmpresa", entity);
		args.put("asistenciaDeViajeEmpresaList", asistenciaDeViajeEmpresaList);

		openWindow("/gui/tarifas/editarAsistenciaDeViajeEmpresa.zul",
				Labels.getLabel("busquedaAsistenciaDeViajeEmpresaController.window.title"), args, MODAL);
	}

	private void refreshLista() {

		HibernateSearchObject<AsistenciaDeViajeEmpresa> asistenciaDeViajeEmpresaBusqueda = new HibernateSearchObject<AsistenciaDeViajeEmpresa>(
				AsistenciaDeViajeEmpresa.class, pagingAsistenciaDeViajeEmpresa.getPageSize());

		asistenciaDeViajeEmpresaBusqueda.addFilterEqual(ACTIVO, Boolean.TRUE);

		asistenciaDeViajeEmpresaBusqueda.addSortAsc("empresa");

		plwAsistenciaDeViajeEmpresa.init(asistenciaDeViajeEmpresaBusqueda, asistenciaDeViajeEmpresaList,
				pagingAsistenciaDeViajeEmpresa);

		if (asistenciaDeViajeEmpresaList.getData().length == 0) {
			try {
				Messagebox.show(Labels.getLabel("MSG.ningunRegistro"),
						Labels.getLabel("busquedaAsistenciaDeViajeEmpresaController.window.title"), Messagebox.OK,
						Messagebox.INFORMATION);
			} catch (InterruptedException ex) {
			}
		}
	}

	public void onClick$btnPesquisa(Event ev) {
		refreshLista();
	}

	public void onClick$btnRefresh(Event ev) {
		refreshLista();
	}

	public void onClick$btnNovo(Event ev) {
		verAsistenciaDeViajeEmpresa(new AsistenciaDeViajeEmpresa());
	}

}
