package com.rjconsultores.ventaboletos.web.gui.controladores.tarifas;

import java.util.HashMap;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Controller;
import org.zkoss.util.resource.Labels;
import org.zkoss.zhtml.Messagebox;
import org.zkoss.zk.ui.Component;
import org.zkoss.zk.ui.event.Event;
import org.zkoss.zk.ui.event.EventListener;
import org.zkoss.zul.Paging;

import com.rjconsultores.ventaboletos.entidad.SeguradoraEmpresa;
import com.rjconsultores.ventaboletos.web.utilerias.MyGenericForwardComposer;
import com.rjconsultores.ventaboletos.web.utilerias.MyListbox;
import com.rjconsultores.ventaboletos.web.utilerias.paginacion.HibernateSearchObject;
import com.rjconsultores.ventaboletos.web.utilerias.paginacion.PagedListWrapper;
import com.rjconsultores.ventaboletos.web.utilerias.render.RenderSeguradoraEmpresa;

@Controller("busquedaSeguradoraEmpresaController")
@Scope("prototype")
public class BusquedaSeguradoraEmpresaController extends MyGenericForwardComposer {

	private static final long serialVersionUID = 1L;

	@Autowired
    private transient PagedListWrapper<SeguradoraEmpresa> plwSeguradoraEmpresa;
	
    private MyListbox seguradoraEmpresaList;
    private Paging pagingSeguradoraEmpresa;


    @Override
    public void doAfterCompose(Component comp) throws Exception {
        super.doAfterCompose(comp);

        seguradoraEmpresaList.setItemRenderer(new RenderSeguradoraEmpresa());
        seguradoraEmpresaList.addEventListener("onDoubleClick", new EventListener() {

            @Override
            public void onEvent(Event event) throws Exception {
            	SeguradoraEmpresa c = (SeguradoraEmpresa) seguradoraEmpresaList.getSelected();
            	verSeguradoraEmpresa(c);
            }
        });

        refreshLista();
    }

    private void verSeguradoraEmpresa(SeguradoraEmpresa o) {
        if (o == null) {
            return;
        }

        Map args = new HashMap();
        args.put("SeguradoraEmpresa", o);
       // args.put("seguroKm", null);
        args.put("seguradoraEmpresaList", seguradoraEmpresaList);

        openWindow("/gui/tarifas/editarSeguradoraEmpresa.zul",
                Labels.getLabel("busquedaSeguradoraEmpresaController.window.title"),
                args, MODAL);
    }

    private void refreshLista() {

        HibernateSearchObject<SeguradoraEmpresa> seguradoraEmpresaBusqueda =
                new HibernateSearchObject<SeguradoraEmpresa>(SeguradoraEmpresa.class,
                pagingSeguradoraEmpresa.getPageSize());



        seguradoraEmpresaBusqueda.addFilterEqual(ACTIVO, Boolean.TRUE);

        
        seguradoraEmpresaBusqueda.addSortAsc("empresa");


        plwSeguradoraEmpresa.init(seguradoraEmpresaBusqueda, seguradoraEmpresaList, pagingSeguradoraEmpresa);

        if (seguradoraEmpresaList.getData().length == 0) {
            try {
                Messagebox.show(Labels.getLabel("MSG.ningunRegistro"),
                        Labels.getLabel("busquedaSeguradoraEmpresaController.window.title"),
                        Messagebox.OK, Messagebox.INFORMATION);
            } catch (InterruptedException ex) {
            }
        }
    }

    public void onClick$btnPesquisa(Event ev) {
        refreshLista();
    }

    public void onClick$btnRefresh(Event ev) {
        refreshLista();
    }

    public void onClick$btnNovo(Event ev) {
        verSeguradoraEmpresa(new SeguradoraEmpresa());
    }

}
